//function definitions

#include "CandleCharting.h"
HANDLE hconsole = GetStdHandle(STD_OUTPUT_HANDLE);


void ChartData::xAxis()
{
	//****************X AXIS***************************
		//print the bottom margin
	cout << setw(11);
	for (size_t col = 0; col < high.size(); col++) //at the bottom of each column output a --
	{
		cout << char(194);
	}
	cout << endl;
	cout << setw(11);
	for (size_t col = high.size(); col-- > 0;) //at the bottom of each column output a --
	{
		if (day.at(col) % 3 == 0)
		{
			if (day.at(col) < 10)
				cout << 0 << day.at(col) << " ";
			if (day.at(col) > 9)
				cout << day.at(col) << " ";
		}
	}
	cout << day.at(0) << endl;
	cout << setw(15) << "-DATE-"<< endl;
	
}

//******************************************************VOLUME BAR CHART***************************************************

void ChartData::volBarChart()
{
	highest = *max_element(vol.begin(), vol.end());
	lowest = *min_element(vol.begin(), vol.end());
	double hcf = (highest - lowest) / 6;
	cout.precision(3);
	cout << setw(10) << "-VOLUME-" << endl;
	//y axis
	for (double rows = ceil(highest); rows >= floor(lowest); rows = rows - hcf) //make number of rows equal to highest value
	{
		double altRow = rows / (1e+9);
		cout <<setw(5) << altRow <<" Bil" << char(180); //print y axis

		for (size_t col = vol.size(); col-- > 0;)
		{
			if (vol.at(col) >= rows)
				cout << char(179);
			else
				cout << " ";

		}
		cout << endl;
	}
	//x axis
	xAxis();

}

//******************************************************CANDLESTICK CHART**************************************************
void ChartData::chart()
{
	//finding the increments of the y axis
	highest = *max_element(high.begin(), high.end());
	lowest = *min_element(low.begin(), low.end());
	double hcf = (highest - lowest) / 40;
	//**************CANDLESTICK CHART******************
	cout << setw(10) << "Price" << endl;
	cout << endl;
	for (double rows = ceil(highest); rows >= floor(lowest); rows = rows - hcf) //make number of rows equal to highest value
	{
		cout << setw(9) << rows << char(180); //print y axis
		for (size_t col = high.size(); col-- > 0;)
		{
			//******************BEARISH CANDLESTICK*******************
			if (open.at(col) > close.at(col)) //check to see if cande is bearish
			{
				if (high.at(col) >= rows) //upper wick condition
				{
					if (open.at(col) >= rows) //open edge of body condition
					{
						if (close.at(col) >= rows) //close edge of body condition
						{
							if (low.at(col) >= rows) // lower wick condition
								cout << " ";
							else
								cout << char(179);
						}
						else
						{
							SetConsoleTextAttribute(hconsole, 4);
							cout << char(219);
							SetConsoleTextAttribute(hconsole, 7);
						}
					}
					else
					{
						cout << char(179);
					}
				}
				else
					cout << " ";
			}
			//***************BULLISH CANDLESTICK*******************
			else if (close.at(col) > open.at(col))
			{
				if (high.at(col) >= rows)
				{
					if (close.at(col) >= rows)
					{
						if (open.at(col) >= rows)
						{
							if (low.at(col) >= rows)
								cout << " ";
							else
								cout << char(179);
						}
						else
						{
							SetConsoleTextAttribute(hconsole, 2);
							cout << char(219);
							SetConsoleTextAttribute(hconsole, 7);
						}
					}
					else
						cout << char(179);
				}
				else
					cout << " ";
			}
		}
		cout << endl;
	}

	xAxis();//print the x axis
	
}

//******************************************************MOVING AVERAGES**************************************************
void ChartData::chartMAs(size_t period)
{
	//finding the increments for the y axis
	double simpleMovingHighest = *max_element(sma.begin(), sma.end());
	double simpleMovingLowest = *min_element(sma.begin(), sma.end());
	double hcf = (simpleMovingHighest - simpleMovingLowest) / 40;

	cout << setw(10) << "Price" << endl;
	cout << endl;

	//*********Y AXIS**********
	for (double rows = ceil(simpleMovingHighest); rows >= floor(simpleMovingLowest); rows -= hcf)
	{
		
		cout << setw(10) << rows << char(180); //print y axis
		for (size_t col = high.size() ; col-- > 0;)
		{
			
			if (col <= high.size()-period) // check to see if there are enough values to plot the first SMA point
			{	
				if (sma.at(col) >= rows)
				{
					if (sma.at(col) >= (rows + hcf)) //check to see if one above it has already been plotted
					{
						cout << " ";
					}
					else
						cout << "*"; //if it reaches, output *
				}
				else
					cout << " "; //if it doesn't, ouput an empty space
			}
			else
				cout << " "; // if there aren't any values to plot yet, output an empty space

		}
		cout << endl;
		
	}
	xAxis();//print the x axis

}
//******************************************************AVERAGE TRUE RANGE**************************************************
void ChartData::chartATR(double period)
{
	//finding the increments for the y axis
	double atrHighest = *max_element(atr.begin(), atr.end());
	double atrLowest = *min_element(atr.begin(), atr.end());
	double hcf = (atrHighest - atrLowest) / 40;

	cout << setw(10) << "-Price-" << endl;
	cout << endl;

	//*********Y AXIS**********
	for (double rows = ceil(atrHighest); rows >= floor(atrLowest); rows -= hcf)
	{
		cout << setw(10) << rows << char(180); //print y axis
		for (size_t col = high.size(); col-- > 0;)
		{

			if (col <= high.size() - period - 1) // check to see if there are enough values to plot the first ATR point
			{
				if (atr.at(col) >= rows)
				{
					if (atr.at(col) >= (rows + hcf)) //check to see if one above it has already been plotted
					{
						cout << " ";
					}
					else
						cout << "o"; //if it reaches, output *
				}
				else
					cout << " "; //if it doesn't, ouput an empty space
			}
			else
				cout << " "; //if there aren't any values to plot yet, output an empty space
		}
		cout << endl;

	}

	xAxis();//print the x axis
}
//******************************************************RELATIVE STRENGTH INDEX**************************************************
void ChartData::chartRSI(double period)
{
	cout << setw(10) << "RSI" << endl;
	cout << endl;
	//*********Y AXIS**********
	for (double rows = 100; rows >= 0; rows -= 5)
	{
		cout << setw(7) << rows << char(180); //print y axis
		for (size_t col = high.size(); col-- > 0;)
		{
			
			if (col <= high.size() - period-1) // check to see if there are enough values to plot the first RSI point
			{
				if (rsi.at(col) >= rows)
				{
					if (rsi.at(col) >= (rows + 5)) //check to see if one above it has already been plotted
					{
						if (rows == 70 || rows == 30)
							cout << "-";
						else
							cout << " "; //if its already plotted above then output empty space
					}
					else
						cout << "*"; //if it reaches, output *
				}
				else
				{
					if(rows == 70 || rows == 30)
						cout << "-";
					else
						cout << " "; //if it doesn't, ouput an empty space
				}
			}
			else
			{
				if (rows == 70 || rows == 30)
					cout << "-";
				else
					cout << " "; //if there aren't any values to plot yet, output an empty space
			}

		}
		cout << endl;
	}

	xAxis();//print the x axis

}






